==> alliance-5.0-20020701.tar.gz: alliance-5.0/bdd/src/bddtest.h <==
/*------------------------------------------------------------\
|                                                             |
| This file is part of the Alliance CAD System Copyright      |
| (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
|                                                             |
| Home page      : http://www-asim.lip6.fr/alliance/          |
| E-mail support : mailto:alliance-support@asim.lip6.fr       |
|                                                             |
| This progam is  free software; you can redistribute it      |
| and/or modify it under the  terms of the GNU Library General|
| Public License as published by the Free Software Foundation |
| either version 2 of the License, or (at your option) any    |
| later version.                                              |
|                                                             |
| Alliance VLSI  CAD System  is distributed  in the hope that |
| it  will be useful, but WITHOUT  ANY WARRANTY;              |
| without even the  implied warranty of MERCHANTABILITY or    |
| FITNESS FOR A PARTICULAR PURPOSE. See the GNU General       |
| Public License for more details.                            |
|                                                             |
| You should have received a copy  of the GNU General Public  |
| License along with the GNU C Library; see the file COPYING. |
| If not, write to the Free Software Foundation, Inc.,        |
| 675 Mass Ave, Cambridge, MA 02139, USA.                     |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
| Tool    :                     Bdd                           |
|                                                             |
| File    :                  bddtest.h                        |
|                                                             |
| Date    :                   03.12.96                        |
|                                                             |
| Author  :               Jacomme Ludovic                     |
|                                                             |
\------------------------------------------------------------*/

# ifndef BDD_TEST_H
# define BDD_TEST_H

/*------------------------------------------------------------\
|                                                             |
|                           Constants                         |
|                                                             |
\------------------------------------------------------------*/

# define BDD_TEST_MAX_COMMAND      42
# define BDD_TEST_BUFFER_SIZE     512

/*------------------------------------------------------------\
|                                                             |
|                            Macro                            |
|                                                             |
\------------------------------------------------------------*/

#ifndef __P
# if defined(__STDC__) ||  defined(__GNUC__)
#  define __P(x) x
# else
#  define __P(x) ()
# endif
#endif

/*------------------------------------------------------------\
|                                                             |
|                            Types                            |
|                                                             |
\------------------------------------------------------------*/

  typedef struct command
  {
    char *NAME;
    void (*FUNCTION)();
    char *COMMENT;

  } command;

/*------------------------------------------------------------\
|                                                             |
|                          Variables                          |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Functions                          |
|                                                             |
\------------------------------------------------------------*/

  static void TestCommandExit();
  static void TestCommandLogout();
  static void TestCommandHelp();

  static void TestCommandAddInput();
  static void TestCommandRenInput();
  static void TestCommandViewInput();
  static void TestCommandAddOutput();
  static void TestCommandDelOutput();
  static void TestCommandDelAssoc();
  static void TestCommandAddAuxiliar();
  static void TestCommandAddAssoc();

  static void TestCommandViewSumProd();

  static void TestCommandViewHeath();
  static void TestCommandViewOutput();
  static void TestCommandViewBlock();
  static void TestCommandViewOper();
  static void TestCommandViewIndex();
  static void TestCommandViewAssoc();
  static void TestCommandViewSystem();
  static void TestCommandViewCircuit();

  static void TestCommandSwapVar();
  static void TestCommandGarbage();
  static void TestCommandSweep();
  static void TestCommandReorder();
  static void TestCommandOptimize();

  static void TestCommandRestrict();
  static void TestCommandCompose();
  static void TestCommandSubstitute();
  static void TestCommandRelProduct();
  static void TestCommandExist();
  static void TestCommandForall();
  static void TestCommandSimpOff();
  static void TestCommandSimpOn();

  static void TestCommandIntersect();
  static void TestCommandImply();
  static void TestCommandCofactor();
  static void TestCommandReduce();
  static void TestCommandSatisfy();
  static void TestCommandFraction();

  static void TestCommandSupport();

  static void TestCommandDumpCircuit();

# endif

==> alliance_5.0-20110203.orig.tar.gz: alliance-5.0/bdd/src/bddtest.h <==
/*------------------------------------------------------------\
|                                                             |
| This file is part of the Alliance CAD System Copyright      |
| (C) Laboratoire LIP6 - Dpartement ASIM Universite P&M Curie|
|                                                             |
| Home page      : http://www-asim.lip6.fr/alliance/          |
| E-mail         : mailto:alliance-users@asim.lip6.fr       |
|                                                             |
| This progam is  free software; you can redistribute it      |
| and/or modify it under the  terms of the GNU Library General|
| Public License as published by the Free Software Foundation |
| either version 2 of the License, or (at your option) any    |
| later version.                                              |
|                                                             |
| Alliance VLSI  CAD System  is distributed  in the hope that |
| it  will be useful, but WITHOUT  ANY WARRANTY;              |
| without even the  implied warranty of MERCHANTABILITY or    |
| FITNESS FOR A PARTICULAR PURPOSE. See the GNU General       |
| Public License for more details.                            |
|                                                             |
| You should have received a copy  of the GNU General Public  |
| License along with the GNU C Library; see the file COPYING. |
| If not, write to the Free Software Foundation, Inc.,        |
| 675 Mass Ave, Cambridge, MA 02139, USA.                     |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
| Tool    :                     Bdd                           |
|                                                             |
| File    :                  bddtest.h                        |
|                                                             |
| Date    :                   03.12.96                        |
|                                                             |
| Author  :               Jacomme Ludovic                     |
|                                                             |
\------------------------------------------------------------*/

# ifndef BDD_TEST_H
# define BDD_TEST_H

/*------------------------------------------------------------\
|                                                             |
|                           Constants                         |
|                                                             |
\------------------------------------------------------------*/

# define BDD_TEST_MAX_COMMAND      42
# define BDD_TEST_BUFFER_SIZE     512

/*------------------------------------------------------------\
|                                                             |
|                            Macro                            |
|                                                             |
\------------------------------------------------------------*/

#ifndef __P
# if defined(__STDC__) ||  defined(__GNUC__)
#  define __P(x) x
# else
#  define __P(x) ()
# endif
#endif

/*------------------------------------------------------------\
|                                                             |
|                            Types                            |
|                                                             |
\------------------------------------------------------------*/

  typedef struct command
  {
    char *NAME;
    void (*FUNCTION)();
    char *COMMENT;

  } command;

/*------------------------------------------------------------\
|                                                             |
|                          Variables                          |
|                                                             |
\------------------------------------------------------------*/
/*------------------------------------------------------------\
|                                                             |
|                          Functions                          |
|                                                             |
\------------------------------------------------------------*/

  static void TestCommandExit();
  static void TestCommandLogout();
  static void TestCommandHelp();

  static void TestCommandAddInput();
  static void TestCommandRenInput();
  static void TestCommandViewInput();
  static void TestCommandAddOutput();
  static void TestCommandDelOutput();
  static void TestCommandDelAssoc();
  static void TestCommandAddAuxiliar();
  static void TestCommandAddAssoc();

  static void TestCommandViewSumProd();

  static void TestCommandViewHeath();
  static void TestCommandViewOutput();
  static void TestCommandViewBlock();
  static void TestCommandViewOper();
  static void TestCommandViewIndex();
  static void TestCommandViewAssoc();
  static void TestCommandViewSystem();
  static void TestCommandViewCircuit();

  static void TestCommandSwapVar();
  static void TestCommandGarbage();
  static void TestCommandSweep();
  static void TestCommandReorder();
  static void TestCommandOptimize();

  static void TestCommandRestrict();
  static void TestCommandCompose();
  static void TestCommandSubstitute();
  static void TestCommandRelProduct();
  static void TestCommandExist();
  static void TestCommandForall();
  static void TestCommandSimpOff();
  static void TestCommandSimpOn();

  static void TestCommandIntersect();
  static void TestCommandImply();
  static void TestCommandCofactor();
  static void TestCommandReduce();
  static void TestCommandSatisfy();
  static void TestCommandFraction();

  static void TestCommandSupport();

  static void TestCommandDumpCircuit();

# endif
